==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-mainmenu/translations/mainmenu_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="113"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="123"/>
        <source>Show/hide main menu</source>
        <translation>Mostrar/ocultar el menú principal</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="522"/>
        <source>Add to desktop</source>
        <translation>Añadir al escritorio</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="530"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="531"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Ya existe un archivo con el mismo nombre.
¿Quiere sobrescribirlo?</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="537"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="538"/>
        <source>The file cannot be overwritten.</source>
        <translation>El archivo no puede ser sobrescrito.</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="544"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Configuración del menú principal</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icono:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Texto del botón:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Tamaño de fuente personalizado:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Archivo de menú</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Archivo de menú:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>Ancho máximo del elemento:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Mostrar entradas coincidentes:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Número máximo de elementos visibles:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtrar las entradas del menú</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Ocultar las entradas del menú al buscar</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Borrar la búsqueda al cerrar el menú</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Atajo de teclado</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Presione el botón para registrar el atajo:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="176"/>
        <source>Choose icon file</source>
        <translation>Elija un archivo de icono</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="178"/>
        <source>Images (*.svg *.png)</source>
        <translation>Imágenes (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="190"/>
        <source>Choose menu file</source>
        <translation>Escoja un archivo de menú</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="192"/>
        <source>Menu files (*.menu)</source>
        <translation>Archivos de menú (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1-1.src.tar.gz: lxqt-panel-2.2.1/plugin-mainmenu/translations/mainmenu_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="108"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="118"/>
        <source>Show/hide main menu</source>
        <translation>Mostrar/ocultar el menú principal</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="467"/>
        <source>Add to desktop</source>
        <translation>Añadir al escritorio</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="475"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="476"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Ya existe un archivo con el mismo nombre.
¿Quiere sobrescribirlo?</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="482"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="483"/>
        <source>The file cannot be overwritten.</source>
        <translation>El archivo no puede ser sobrescrito.</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="489"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu Settings</source>
        <translation>Configuración del menú principal</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="26"/>
        <source>Icon:</source>
        <translation>Icono:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="50"/>
        <source>Button text:</source>
        <translation>Texto del botón:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="67"/>
        <source>Custom font size:</source>
        <translation>Tamaño de fuente personalizado:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="77"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="96"/>
        <source>Menu file</source>
        <translation>Archivo de menú</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="102"/>
        <source>Menu file:</source>
        <translation>Archivo de menú:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="147"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="181"/>
        <source>Max. item width:</source>
        <translation>Ancho máximo del elemento:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="160"/>
        <source>Show matching entries:</source>
        <translation>Mostrar entradas coincidentes:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="167"/>
        <source>Maximum visible items:</source>
        <translation>Número máximo de elementos visibles:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="153"/>
        <source>Filter menu entries</source>
        <translation>Filtrar las entradas del menú</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="188"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="201"/>
        <source>Hide menu entries while searching</source>
        <translation>Ocultar las entradas del menú al buscar</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="208"/>
        <source>Clear search upon showing menu</source>
        <translation>Borrar la búsqueda al cerrar el menú</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="118"/>
        <source>Keyboard Shortcut</source>
        <translation>Atajo de teclado</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="124"/>
        <source>Click the button to record shortcut:</source>
        <translation>Presione el botón para registrar el atajo:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="176"/>
        <source>Choose icon file</source>
        <translation>Elija un archivo de icono</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="178"/>
        <source>Images (*.svg *.png)</source>
        <translation>Imágenes (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="190"/>
        <source>Choose menu file</source>
        <translation>Escoja un archivo de menú</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="192"/>
        <source>Menu files (*.menu)</source>
        <translation>Archivos de menú (*.menu)</translation>
    </message>
</context>
</TS>
